<!-- template from https://github.com/othneildrew/Best-README-Template/blob/master/README.md -->
<!-- 工具篇-如何制作属于你自己的pip包: https://zhuanlan.zhihu.com/p/557498429 -->
<!-- PROJECT LOGO -->
<br />
<div align="center">
  <a href="https://github.com/othneildrew/Best-README-Template">
    <img src="https://bkimg.cdn.bcebos.com/pic/0bd162d9f2d3572c11df7d04b042742762d0f6036593?x-bce-process=image/watermark,image_d2F0ZXIvYmFpa2UxMTY=,g_7,xp_5,yp_5/format,f_auto" alt="Logo" width="80" height="80">
  </a>

  <h3 align="center">juans</h3>

  <p align="center">
    juans is a kind of attitude when we competing with others!
    <!-- <br />
    <a href="https://github.com/othneildrew/Best-README-Template"><strong>Explore the docs »</strong></a>
    <br />
    <br />
    <a href="https://github.com/othneildrew/Best-README-Template">View Demo</a>
    ·
    <a href="https://github.com/othneildrew/Best-README-Template/issues">Report Bug</a>
    ·
    <a href="https://github.com/othneildrew/Best-README-Template/issues">Request Feature</a> -->
  </p>
</div>


<!-- TABLE OF CONTENTS -->
<details open>
  <summary>Table of Contents</summary>
  <ol>
    <li>
      <a href="#about-the-project">About The Project</a>
    </li>
    <li>
      <a href="#getting-started">Getting Started</a>
      <ul>
        <li><a href="#prerequisites">Prerequisites</a></li>
        <li><a href="#example">Example</a></li>
      </ul>
    </li>
    <li><a href="#license">License</a></li>
    <li><a href="#contact">Contact</a></li>
  </ol>
</details>


# About The Project
juans is a package for fast iterating your deep learning experiment, it has some helpful tricks which are often used in competition and work, and more tricks are on the way!

<!-- GETTING STARTED -->
## Getting Started
### Installation
```python
pip install juans
```

### Example
```python
to be added
```
<p align="right">(<a href="#readme-top">back to top</a>)</p>

<!-- LICENSE -->
## License
Distributed under the MIT License. See `LICENSE` for more information.
<p align="right">(<a href="#readme-top">back to top</a>)</p>

<!-- CONTACT -->
## Contact
Your Name - [易灿](https://twitter.com/your_username) - 972775099@qq.com
<p align="right">(<a href="#readme-top">back to top</a>)</p>